@@ -62,7 +62,7 @@ class Sensor(SensorBase):
             name="post_data",
             caption="POST Data",
             default="",
-            help="Enter HTTP Headers as dictionary. e.g. {'my header':'my value'}. Only used when Request Type is POST",
+            help="Enter POST data as dictionary. e.g. {'my header':'my value'}. Only used when Request Type is POST",
         )
         http_def_group_target.add_field(
             field_type="edit",
@@ -81,14 +81,14 @@ class Sensor(SensorBase):
             headers = None
             post_data = None
             acceptable_status_codes = []
-            if not task_data["acceptable_status_codes"] == "":
+            if task_data["acceptable_status_codes"]:
                 acceptable_status_codes = [int(i) for i in task_data["acceptable_status_codes"].split(",")]
-            if not task_data["headers"] == "":
+            if task_data["headers"]:
                 try:
                     headers = json.loads(task_data["headers"])
                 except JSONDecodeError:
                     raise
-            if not task_data["post_data"] == "" and task_data["request_type"] == "POST":
+            if task_data["post_data"] and task_data["request_type"] == "POST":
                 try:
                     post_data = json.loads(task_data["post_data"])
                 except JSONDecodeError:
