@@ -40,12 +40,15 @@ class Sensor(SensorPSUtilBase):
         try:
             uname = platform.uname()
             probe_temp_data.message = f"Temperatures on {uname.system}, everything OK"
+            fahrenheit = False
+            if task_data["celfar"] == "2":
+                fahrenheit = True
 
-            temperatures = self.get_system_temperatures(fahrenheit=True if task_data["celfar"] == 2 else False)
+            temperatures = self.get_system_temperatures(fahrenheit=fahrenheit)
             if temperatures:
                 for name, entries in temperatures.items():
                     for entry in entries:
-                        probe_temp_data.add_temperature_channel(entry.label or name, entry.current)
+                        probe_temp_data.add_temperature_channel(entry.label or name, entry.current, task_data["celfar"])
 
             else:
                 probe_temp_data.error = "Exception"
